@@ -8,8 +8,23 @@ import scipy.misc
 import numdifftools.fornberg as ndf
 import numdifftools
 
-def prod(C, f, df=None, phi=None, psi=None, absTol=1e-12, relTol=1e-12, divMin=3,
-    divMax=15, m=2, intMethod='quad', integerTol=inf, verbose=False, callback=None):
+
+def prod(
+    C,
+    f,
+    df=None,
+    phi=None,
+    psi=None,
+    absTol=1e-12,
+    relTol=1e-12,
+    divMin=3,
+    divMax=15,
+    m=2,
+    intMethod="quad",
+    integerTol=inf,
+    verbose=False,
+    callback=None,
+):
     r"""
     Compute the symmetric bilinear form used in (1.12) of [KB]_.
 
@@ -78,49 +93,57 @@ def prod(C, f, df=None, phi=None, psi=None, absTol=1e-12, relTol=1e-12, divMin=3
     .. [KB] "Computing the zeros of analytic functions" by Peter Kravanja,
         Marc Van Barel, Springer 2000
     """
-    if intMethod == 'romb':
+    if intMethod == "romb":
         N = 1
         k = 0
         I = []
 
-        while k < divMax and (len(I) < divMin
-            or (abs(I[-2] - I[-1]) > absTol and abs(I[-2] - I[-1]) > relTol*abs(I[-1]))
-            or (abs(I[-3] - I[-2]) > absTol and abs(I[-3] - I[-2]) > relTol*abs(I[-2]))
+        while k < divMax and (
+            len(I) < divMin
+            or (
+                abs(I[-2] - I[-1]) > absTol and abs(I[-2] - I[-1]) > relTol * abs(I[-1])
+            )
+            or (
+                abs(I[-3] - I[-2]) > absTol and abs(I[-3] - I[-2]) > relTol * abs(I[-2])
+            )
             or abs(int(round(I[-1].real)) - I[-1].real) > integerTol
-            or abs(I[-1].imag) > integerTol):
-            N = 2*N
-            t = np.linspace(0,1,N+1)
+            or abs(I[-1].imag) > integerTol
+        ):
+            N = 2 * N
+            t = np.linspace(0, 1, N + 1)
             k += 1
-            dt = t[1]-t[0]
+            dt = t[1] - t[0]
 
             integrals = []
             for segment in C.segments:
                 # compute/retrieve function evaluations
-                fVal = segment.trap_values(f,k)
+                fVal = segment.trap_values(f, k)
 
                 if df is None:
                     # approximate df/dz with finite difference
                     dfdt = np.gradient(fVal, dt)
-                    dfVal = dfdt/segment.dzdt(t)
+                    dfVal = dfdt / segment.dzdt(t)
                 else:
-                    dfVal = segment.trap_values(df,k)
+                    dfVal = segment.trap_values(df, k)
 
-                segment_integrand = dfVal/fVal*segment.dzdt(t)
+                segment_integrand = dfVal / fVal * segment.dzdt(t)
                 if phi is not None:
-                    segment_integrand = segment.trap_values(phi,k)*segment_integrand
+                    segment_integrand = segment.trap_values(phi, k) * segment_integrand
                 if psi is not None:
-                    segment_integrand = segment.trap_values(psi,k)*segment_integrand
+                    segment_integrand = segment.trap_values(psi, k) * segment_integrand
 
-                segment_integral = scipy.integrate.romb(segment_integrand, dx=dt, axis=-1)/(2j*pi)
+                segment_integral = scipy.integrate.romb(
+                    segment_integrand, dx=dt, axis=-1
+                ) / (2j * pi)
                 integrals.append(segment_integral)
 
             I.append(sum(integrals))
 
             if verbose:
                 if k > 1:
-                    print(k, 'I', I[-1], 'err', I[-2] - I[-1])
+                    print(k, "I", I[-1], "err", I[-2] - I[-1])
                 else:
-                    print(k, 'I', I[-1])
+                    print(k, "I", I[-1])
 
             if callback is not None:
                 err = abs(I[-2] - I[-1]) if k > 1 else None
@@ -129,7 +152,7 @@ def prod(C, f, df=None, phi=None, psi=None, absTol=1e-12, relTol=1e-12, divMin=3
 
         return I[-1], abs(I[-2] - I[-1])
 
-    elif intMethod == 'quad':
+    elif intMethod == "quad":
         if df is None:
             df = numdifftools.Derivative(f, order=m)
             # df = lambda z: scipy.misc.derivative(f, z, dx=1e-8, n=1, order=3)
@@ -141,42 +164,59 @@ def prod(C, f, df=None, phi=None, psi=None, absTol=1e-12, relTol=1e-12, divMin=3
         I, err = 0, 0
         for segment in C.segments:
             integrand_cache = {}
+
             def integrand(t):
                 if t in integrand_cache.keys():
                     i = integrand_cache[t]
                 else:
                     z = segment(t)
-                    i = (df(z)/f(z))/(2j*pi) * segment.dzdt(t)
+                    i = (df(z) / f(z)) / (2j * pi) * segment.dzdt(t)
                     if phi is not None:
-                        i = phi(z)*i
+                        i = phi(z) * i
                     if psi is not None:
-                        i = psi(z)*i
+                        i = psi(z) * i
                     integrand_cache[t] = i
                 return i
 
             # integrate real part
             integrand_real = lambda t: np.real(integrand(t))
-            result_real = scipy.integrate.quad(integrand_real, 0, 1, full_output=1, epsabs=absTol, epsrel=relTol)
+            result_real = scipy.integrate.quad(
+                integrand_real, 0, 1, full_output=1, epsabs=absTol, epsrel=relTol
+            )
             I_real, abserr_real, infodict_real = result_real[:3]
 
             # integrate imaginary part
             integrand_imag = lambda t: np.imag(integrand(t))
-            result_imag = scipy.integrate.quad(integrand_imag, 0, 1, full_output=1, epsabs=absTol, epsrel=relTol)
+            result_imag = scipy.integrate.quad(
+                integrand_imag, 0, 1, full_output=1, epsabs=absTol, epsrel=relTol
+            )
             I_imag, abserr_imag, infodict_imag = result_imag[:3]
 
-            I   += I_real + 1j*I_imag
-            err += abserr_real + 1j*abserr_imag
+            I += I_real + 1j * I_imag
+            err += abserr_real + 1j * abserr_imag
 
         return I, abs(err)
 
     else:
         raise ValueError("intMethod must be either 'romb' or 'quad'")
 
+
 class RootError(RuntimeError):
     pass
 
-def count_roots(C, f, df=None, NIntAbsTol=0.07, integerTol=0.1, divMin=3,
-    divMax=15, m=2, intMethod='quad', verbose=False):
+
+def count_roots(
+    C,
+    f,
+    df=None,
+    NIntAbsTol=0.07,
+    integerTol=0.1,
+    divMin=3,
+    divMax=15,
+    m=2,
+    intMethod="quad",
+    verbose=False,
+):
     r"""
     For a function of one complex variable, f(z), which is analytic in
     and within the contour C, return the number of zeros (counting
@@ -240,20 +280,35 @@ def count_roots(C, f, df=None, NIntAbsTol=0.07, integerTol=0.1, divMin=3,
         within the contour C.
     """
     if verbose:
-        print('Computing number of roots within', C)
+        print("Computing number of roots within", C)
 
     with warnings.catch_warnings():
         # ignore warnings and catch if I is NaN later
         warnings.simplefilter("ignore")
-        I, err = prod(C, f, df, absTol=NIntAbsTol, relTol=0, divMin=divMin,
-            divMax=divMax, m=m, intMethod=intMethod, verbose=verbose, integerTol=integerTol)
+        I, err = prod(
+            C,
+            f,
+            df,
+            absTol=NIntAbsTol,
+            relTol=0,
+            divMin=divMin,
+            divMax=divMax,
+            m=m,
+            intMethod=intMethod,
+            verbose=verbose,
+            integerTol=integerTol,
+        )
 
-    if intMethod == 'romb':
-        C._numberOfDivisionsForN = int(np.log2(len(C.segments[0]._trapValuesCache[f])-1))
+    if intMethod == "romb":
+        C._numberOfDivisionsForN = int(
+            np.log2(len(C.segments[0]._trapValuesCache[f]) - 1)
+        )
 
     if np.isnan(I):
-        raise RootError("""Result of integral is an invalid value.
-                           Most likely because of a divide by zero error.""")
+        raise RootError(
+            """Result of integral is an invalid value.
+                           Most likely because of a divide by zero error."""
+        )
 
     elif abs(int(round(I.real)) - I.real) < integerTol and abs(I.imag) < integerTol:
         # integral is sufficiently close to an integer
@@ -262,4 +317,3 @@ def count_roots(C, f, df=None, NIntAbsTol=0.07, integerTol=0.1, divMin=3,
 
     else:
         raise RootError("The number of enclosed roots has not converged to an integer")
-
