@@ -4,11 +4,12 @@ from numpydoc.docscrape import FunctionDoc
 def remove_para(*paras):
     def wrapper(func):
         doc = FunctionDoc(func)
-        for i, p in enumerate(doc['Parameters'][:]):
-            if p.name.split(':')[0].rstrip() in paras:
-                del doc['Parameters'][i]
+        for i, p in enumerate(doc["Parameters"][:]):
+            if p.name.split(":")[0].rstrip() in paras:
+                del doc["Parameters"][i]
         func.__doc__ = doc
         return func
+
     return wrapper
 
 
@@ -19,6 +20,7 @@ def update_docstring(**dic):
             doc[k] = v
         func.__doc__ = doc
         return func
+
     return wrapper
 
 
